#[repr(transparent)]pub struct Mod(pub u32);Expand description
Watchdog mode register. This register contains the basic mode and status of the Watchdog Timer.
Tuple Fields
0: u32Implementations
Sourceimpl Mod
impl Mod
Sourcepub const fn wden(&self) -> Wden
pub const fn wden(&self) -> Wden
Watchdog enable bit. Once this bit is set to one and a watchdog feed is performed, the watchdog timer will run permanently.
Sourcepub const fn set_wden(&mut self, val: Wden)
pub const fn set_wden(&mut self, val: Wden)
Watchdog enable bit. Once this bit is set to one and a watchdog feed is performed, the watchdog timer will run permanently.
Sourcepub const fn wdreset(&self) -> Wdreset
pub const fn wdreset(&self) -> Wdreset
Watchdog reset enable bit. Once this bit has been written with a 1 it cannot be re-written with a 0.
Sourcepub const fn set_wdreset(&mut self, val: Wdreset)
pub const fn set_wdreset(&mut self, val: Wdreset)
Watchdog reset enable bit. Once this bit has been written with a 1 it cannot be re-written with a 0.
Sourcepub const fn wdtof(&self) -> bool
pub const fn wdtof(&self) -> bool
Watchdog time-out flag. Set when the watchdog timer times out, by a feed error, or by events associated with WDPROTECT. Cleared by software writing a 0 to this bit position. Causes a chip reset if WDRESET = 1.
Sourcepub const fn set_wdtof(&mut self, val: bool)
pub const fn set_wdtof(&mut self, val: bool)
Watchdog time-out flag. Set when the watchdog timer times out, by a feed error, or by events associated with WDPROTECT. Cleared by software writing a 0 to this bit position. Causes a chip reset if WDRESET = 1.
Sourcepub const fn wdint(&self) -> bool
pub const fn wdint(&self) -> bool
Warning interrupt flag. Set when the timer is at or below the value in WDWARNINT. Cleared by software writing a 1 to this bit position. Note that this bit cannot be cleared while the WARNINT value is equal to the value of the TV register. This can occur if the value of WARNINT is 0 and the WDRESET bit is 0 when TV decrements to 0.
Sourcepub const fn set_wdint(&mut self, val: bool)
pub const fn set_wdint(&mut self, val: bool)
Warning interrupt flag. Set when the timer is at or below the value in WDWARNINT. Cleared by software writing a 1 to this bit position. Note that this bit cannot be cleared while the WARNINT value is equal to the value of the TV register. This can occur if the value of WARNINT is 0 and the WDRESET bit is 0 when TV decrements to 0.
Sourcepub const fn wdprotect(&self) -> Wdprotect
pub const fn wdprotect(&self) -> Wdprotect
Watchdog update mode. This bit can be set once by software and is only cleared by a reset.
Sourcepub const fn set_wdprotect(&mut self, val: Wdprotect)
pub const fn set_wdprotect(&mut self, val: Wdprotect)
Watchdog update mode. This bit can be set once by software and is only cleared by a reset.